geowatch.tasks.tracking.old\_polygon\_extraction module
=======================================================

.. automodule:: geowatch.tasks.tracking.old_polygon_extraction
   :members:
   :undoc-members:
   :show-inheritance:
